@@ -1,4 +1,4 @@
-/*	$OpenBSD: misc.c,v 1.75 2020/07/22 19:20:41 millert Exp $	*/
+/*	$OpenBSD: misc.c,v 1.76 2020/10/26 18:16:51 tb Exp $	*/
 
 /*
  * Miscellaneous functions
@@ -292,7 +292,7 @@ change_flag(enum sh_flag f,
 		}
 	} else
 	/* Turning off -p? */
-	if (f == FPRIVILEGED && oldval && !newval && issetugid() &&
+	if (f == FPRIVILEGED && oldval && !newval && oksh_issetugid() &&
 	    !dropped_privileges) {
 		gid_t gid = getgid();
 
@@ -305,6 +305,7 @@ change_flag(enum sh_flag f,
 		    "exec tty", NULL) == -1)
 			bi_errorf("pledge fail");
 #endif
+
 		dropped_privileges = 1;
 	} else if (f == FPOSIX && newval) {
 		Flag(FBRACEEXPAND) = 0;
@@ -715,7 +716,7 @@ do_gmatch(const unsigned char *s, const unsigned char *se,
 static int
 posix_cclass(const unsigned char *pattern, int test, const unsigned char **ep)
 {
-	struct cclass *cc;
+	const struct cclass *cc;
 	const unsigned char *colon;
 	size_t len;
 	int rval = 0;
